<template>
    <div class="product_listing">
        <div class="row col-12" v-if="list.length<=0">Products Not Found</div>
        <div v-else>
            <div class="price_filter mb-0"><v-app class="vue-front-end-fixed" v-if="auth_check">
                <v-switch
                  v-model="show_pricing"
                  inset
                  color="#47248C"
                  label="Show/Hide Pricing"
                ></v-switch>
            </v-app></div>
            <div class="row">
                <div class="col-6 col-sm-6 col-md-4 col-lg-4  col-xl-3"
                v-for="(product,i) in list" :key="i"
                >
                    <div class="product_item" v-if="product.default_category!=null"> <a :href="buildProductUrl(product)">
                        <div class="product_flag">
                          <div class="new_item" v-if="checkNewItem(product)==true"><span class="material-icons">local_offer</span> Brand New</div>
                          <div class="special_item" v-else-if="checkSpecialItem(product)==true"><i class="fas fa-medal"></i> On Special</div>
                        </div>
                        <div class="product_img" >
                            <img v-if="product.file_upload.length>0" :src="`${options.storage_root}/`+product.file_upload[0].upload.uploaded_path" :title="(product.file_upload[0].title!=null && product.file_upload[0].title!='') ? product.file_upload[0].title : product.name" :alt="(product.file_upload[0].alt_text!=null && product.file_upload[0].alt_text!='') ? product.file_upload[0].alt_text : product.name">
                            <img :alt="product.name" v-else src="/images/no-img.png">
                            </div>
                        <h2>{{ product.name }}</h2>
                        <div class="pricings"  >
                             <ul>
                                <li v-for="(pricing,ind) in Object.values(product.pricings)" :key="ind">Available <span v-if="pricing.rent_term!=null">{{ pricing.rent_term.name }}</span><span v-else>{{ pricing.custom_rent_term }}</span> 
                                    <span v-if="auth_check && show_pricing">
                                                    - ${{(pricing.price*1).toFixed(2)}}
                                                </span>
                                </li>
                            </ul>
                        </div>
                        <div class="retail_price" v-if="auth_check && show_pricing">RETAIL PRICE : ${{(product.retail_price*1).toFixed(2)}}</div>
                        <div class="retail_price" v-else> </div>
                        <a :href="buildProductUrl(product)" class="view_btn_mobile">View Pricing</a>
                        </a> </div>
                </div>
            </div>
        </div>
    </div>
</template>
<script>
var moment=require('moment');
import {cloneDeep} from 'lodash';
import options from '~/assets/options';
export default {
    props : ['list','pricings'],
    data() {
        return {
        options     : options,
        show_pricing : true,
        auth_check  : Boolean(this.$store.state.front_end_data.auth_check),
        location_name   : this.$store.state.front_end_data.location_name,
        domain      : this.$store.state.front_end_data.domain,
        }
    },
    mounted() {
        console.log(this.auth_check);
        this.location_name = this.$store.state.front_end_data.location_name;
        this.$store.watch(() => this.$store.state.front_end_data, async () => {
             this.location_name = this.$store.state.front_end_data.location_name;
        }); 
        
        this.$axios.$get('/check-auth')
        .then(resp=>{
            this.auth_check = resp.auth_check;
        });
    },
    methods: {
        buildProductUrl(product) {
            let parent_category = (product.default_category.parent_category != null) ? product.default_category.parent_category.link_rewrite + '/' : "";
            let route = '/' + this.location_name + '/' + parent_category + product.default_category.link_rewrite + '/' + product.link_rewrite;
            return route;
        },
        checkNewItem(product) {
            if(!product.detail.new_item) {
                return false;
            }
            let current_date  = moment();
            if(current_date.diff(moment(product.detail.new_till,'YYYY-MM-DD'))<=0) {
                return true;
            }
            return false;
        },
        checkSpecialItem(product) {
            if(!product.detail.special_item) {
                return false;
            }
            let current_date  = moment();
            if(current_date.diff(moment(product.detail.special_till,'YYYY-MM-DD'))<=0) {
                return true;
            }
            return false;
        }
    }
}
</script>
